==> FakesUsers-2.0.tar.gz: FakesUsers-2.0/FakesUsers/FakesUsers.py <==
import random

class Fu:
    def __init__(self):
        self.name_m = ['Андрей','Афанасий','Абдул','Антон','Архип','Анатолий','Александр','Алексей','Альберт','Аксен',
                        'Богдан','Борис','Бронислав','Буклаг',
                        'Вадим','Владислав','Виктор','Валерий','Валентин','Василий','Виталий','Всеволод',
                        'Давид','Давыд','Даниель','Данил','Даниил','Дмитрий','Доброслав'
                        'Евгений','Евсений','Ефрем','Епифан','Егор',
                        'Жан',
                        'Завид','Захар',
                        'Иван','Игнат','Игорь','Иосиф','Изяслав','Илья','Ильнар',
                        'Кирилл','Казимир','Кузьма',
                        'Ладислав',
                        'Мазай','Макар','Максим','Марат', 'Мурат', 'Матвей','Марк', 'Мирослав',
                        'Никита','Нифёд','Николай','Назар',
                        'Олимп','Олег',
                        'Павел','Пётр',
                        'Роман','Родим','Радислав','Руслан','Рюрик',
                        'Савелий','Савва','Семён','Станислав','Спартак',
                        'Фёдор','Филипп','Федот',
                        'Эдвард','Эльдар','Эдгар','Эрик',
                        'Юрий','Юлий',
                        'Якив','Яков','Ян','Ярополк','Ярослав',]
        
        self.surname_m = ['Аношкин','Апатов','Апятов','Александров','Авлипов','Анатошкин','Аримченко','Абаранов','Адамов','Авличекко',
                        'Бытряков','Битряков','Борисов','Балипин','Базякин','Бурятов','Батурин',
                        'Ветров','Ветряков','Вадмиран','Вичатов','Викрович','Взаров','Версталин','Вокупин',
                        'Демитров','Донской','Денистарин','Дуров','Дамиченко','Доброградов','Далинин'
                        'Ермаков','Ефмеич','Егоров','Екатин',
                        'Жаровцев','Жирин','Жостченко','Жипин','Жилин'
                        'Задоров','Затриков','Зосин','Зазарин','Захаров','Захаев',
                        'Ильбанов','Инитаров','Известин','Итмирин','Изаченко','Избанов','Иоритов',
                        'Кристалин','Крост','Кисмисов',
                        'Лебедев','Литартасов','Ликрасов','Лесуч','Лобиченко',
                        'Митин','Матросов','Миклин','Меривич', 'Муратов', 'Матвеев','Мустин','Маслеников',
                        'Надурин','Нифёдов','Назаров','Николаев',
                        'Останткин','Остмов',
                        'Петроградов','Подушкин','Пирин','Пиров',
                        'Рокосовский','Радимов','Рютриков','Русланов','Ралин',
                        'Сантропов','Семёнов','Семечкин','Стасин','Спартаков',
                        'Фёдоров','Филиморов','Филатов',
                        'Хитров','Хитбаров','Хабарин',
                        'Шевцов','Шитрин','Шитин'
                        'Эдринский','Эшинский','Эпченко','Эрикс',
                        'Ютропов','Юлиев',
                        'Ярков','Яковлев','Ялубин','Явилин','Яшин',]
        
        self.name_f = [ 'Аглая','Арина','Арина','Анна','Августина','Аделина','Ангелина','Анжела','Анфиса','Ася', 'Анастасия', 'Александра',
                        'Валентина','Владислава','Ваннеса','Виктория','Вероника','Вера',
                        'Галина',
                        'Дария','Диана','Дора',
                        'Елена','Евгения','Ева','Екатерина','Елизавета',
                        'Жанна',
                        'Зарина','Зоя',
                        'Инна','Ива','Ирина',
                        'Калина','Кира', 'Кристина'
                        'Лариса','Любовь','Лина',
                        'Майя','Марина','Мария','Марьяна',
                        'Ника','Надежда',
                        'Олеся','Оксана','Ольга',
                        'Полина',
                        'Рая','Раиса','Роза','Рита',
                        'Сабина','София','Стефания',
                        'Таисия','Татьяна',
                        'Эля','Эльга',
                        'Яна','Ярина',]
        
        self.surname_f = ['Алианна','Альяна','Атрасова','Апяткова','Авиолова','Анатошкина','Адианова','Асокина','Асотина','Алимарова',
                        'Бистибюлина','Бистинова','Бильбина','Балина','Базякина','Бурова','Батросова',
                        'Виталина','Верченко','Вистибюлина','Волчанова','Васюткина','Взирова','Ветрова','Вилина',
                        'Добровая','Дианнова','Деченко','Дякина','Дасимова','Добрич','Долинина'
                        'Етиспатова','Еровенич','Есушкина','Едурина',
                        'Жилинна','Жигулич','Житрипевич','Жигина','Жорина'
                        'Зимаидова','Зимина','Зосина','Зарецская','Замитрова','Зюсина',
                        'Ильнасова','Ирибинко','Истучева','Исшенко','Ипритова','Илизова','Иоритова',
                        'Кристальная','Кристинова','Космович',
                        'Ликрасова','Литрасова','Лобина','Логина','Лосинова',
                        'Миликанова','Мутулина','Марошина','Мертеич', 'Муратова', 'Матвеева','Мулина','Мастович',
                        'Никитова','Неримова','Настюшина','Николаева',
                        'Осенняя','Отмирова',
                        'Петрокамчатская','Полинина','Пирова','Пасутина',
                        'Роловинина','Ракусина','Рюрович','Руслаченко','Ралина','Родова',
                        'Сандалина','Семикрасова','Сачкова','Салтыкова','Спорина',
                        'Фёдорова','Филиморова','Филатова',
                        'Хирипова','Хиширина','Хочубина',
                        'Шевцова','Шитина','Шитрина'
                        'Эдолинова','Эльдарова','Эпченко','Эпистатова',
                        'Ютропова','Юлиева',
                        'Яркова','Яковлева','Ялубина','Явилина','Яшина',]
        
        self.num_part1 = ['805','810','820','850','870','880','890','895','899',]

        self.num_part2 = ['2415537','4636643','6438943','0077543','6536673','3564575','3513355','0006559',
                       '9997590','8654581','1010853','6695888','4256343','6476754','1215467','53674367',]
        
        self.email = ['rei793h','AlexHyIO','PORAMT1K','lsui1994','4345g2aw24y',
                      'georagl:wedmak','neomeo228','fifynya','930ip42','4444ererer4444',
                      'uow54io','xxxkeepmedownxxx','tytyr1n3','fil4rok','0101hh0101','QQooyyuurrnnIIwwqqxxzzQQ','popyt1k','tyrn1k','776',]
        
        self.email_index = ['@gmail.com','@outlook.com','@mcrs.com','@pytest.py',]

        self.faddres = ['Грибоедова','Ленина','Жаргонская','Сосоновая','Еловая',
                  'Пугачева','Комунистическая','Социалистическая','Дектярёва','Гагарина',
                  'Черная','Победителей','Мира','Малеева','Захарова', '20 октября']

    def fakename_male(self):
        fakenm = random.randint(0, len(self.name_m) -1)
        fakesm = random.randint(0, len(self.surname_m) -1)
        return(f'{self.name_m[fakenm]} {self.surname_m[fakesm]}')
    
    def fakename_female(self):
        fakenf = random.randint(0, len(self.name_f) -1)
        fakesf = random.randint(0, len(self.name_f) -1)
        return(f'{self.name_f[fakenf]} {self.surname_f[fakesf]}')

    def fake_number(self):
        fakenum1 = random.randint(0, len(self.num_part1) -1)
        fakenum2 = random.randint(0, len(self.num_part2) -1)
        return(f'+7{self.num_part1[fakenum1]}{self.num_part2[fakenum2]}')
    
    def fake_addres(self):
        fakeaddres = random.randint(0, len(self.faddres) -1)
        return(f'ул. {self.faddres[fakeaddres]} {random.randint(1, 120)}')
    
    def fake_email(self):
        fakeei = random.randint(0, len(self.email_index) -1)
        fakee = random.randint(0, len(self.email) -1)
        return(f'{self.email[fakee]}{self.email_index[fakeei]}')

if __name__ == '__main__':
    fu = Fu()

==> FakesUsers-2.1.tar.gz: FakesUsers-2.1/FakesUsers/FakesUsers.py <==
import random

class Fu:
    def __init__(self):
        self.name_m = ['Андрей','Афанасий','Абдул','Антон','Архип','Анатолий','Александр','Алексей','Альберт','Аксен',
                        'Богдан','Борис','Бронислав','Буклаг',
                        'Вадим','Владислав','Виктор','Валерий','Валентин','Василий','Виталий','Всеволод',
                        'Давид','Давыд','Даниель','Данил','Даниил','Дмитрий','Доброслав',
                        'Евгений','Евсений','Ефрем','Епифан','Егор',
                        'Жан',
                        'Завид','Захар',
                        'Иван','Игнат','Игорь','Иосиф','Изяслав','Илья','Ильнар',
                        'Кирилл','Казимир','Кузьма',
                        'Ладислав',
                        'Мазай','Макар','Максим','Марат', 'Мурат', 'Матвей','Марк', 'Мирослав',
                        'Никита','Нифёд','Николай','Назар',
                        'Олимп','Олег',
                        'Павел','Пётр',
                        'Роман','Родим','Радислав','Руслан','Рюрик',
                        'Савелий','Савва','Семён','Станислав','Спартак',
                        'Фёдор','Филипп','Федот',
                        'Эдвард','Эльдар','Эдгар','Эрик',
                        'Юрий','Юлий',
                        'Якив','Яков','Ян','Ярополк','Ярослав',]
        
        self.surname_m = ['Аношкин','Апатов','Апятов','Александров','Авлипов','Анатошкин','Аримченко','Абаранов','Адамов','Авличекко',
                        'Бытряков','Битряков','Борисов','Балипин','Базякин','Бурятов','Батурин',
                        'Ветров','Ветряков','Вадмиран','Вичатов','Викрович','Взаров','Версталин','Вокупин',
                        'Демитров','Донской','Денистарин','Дуров','Дамиченко','Доброградов','Далинин',
                        'Ермаков','Ефмеич','Егоров','Екатин',
                        'Жаровцев','Жирин','Жостченко','Жипин','Жилин',
                        'Задоров','Затриков','Зосин','Зазарин','Захаров','Захаев',
                        'Ильбанов','Инитаров','Известин','Итмирин','Изаченко','Избанов','Иоритов',
                        'Кристалин','Крост','Кисмисов',
                        'Лебедев','Литартасов','Ликрасов','Лесуч','Лобиченко',
                        'Митин','Матросов','Миклин','Меривич', 'Муратов', 'Матвеев','Мустин','Маслеников',
                        'Надурин','Нифёдов','Назаров','Николаев',
                        'Останткин','Остмов',
                        'Петроградов','Подушкин','Пирин','Пиров',
                        'Рокосовский','Радимов','Рютриков','Русланов','Ралин',
                        'Сантропов','Семёнов','Семечкин','Стасин','Спартаков',
                        'Фёдоров','Филиморов','Филатов',
                        'Хитров','Хитбаров','Хабарин',
                        'Шевцов','Шитрин','Шитин',
                        'Эдринский','Эшинский','Эпченко','Эрикс',
                        'Ютропов','Юлиев',
                        'Ярков','Яковлев','Ялубин','Явилин','Яшин',]
        
        self.name_f = [ 'Аглая','Арина','Арина','Анна','Августина','Аделина','Ангелина','Анжела','Анфиса','Ася', 'Анастасия', 'Александра',
                        'Валентина','Владислава','Ваннеса','Виктория','Вероника','Вера',
                        'Галина',
                        'Дария','Диана','Дора',
                        'Елена','Евгения','Ева','Екатерина','Елизавета',
                        'Жанна',
                        'Зарина','Зоя',
                        'Инна','Ива','Ирина',
                        'Калина','Кира', 'Кристина',
                        'Лариса','Любовь','Лина',
                        'Майя','Марина','Мария','Марьяна',
                        'Ника','Надежда',
                        'Олеся','Оксана','Ольга',
                        'Полина',
                        'Рая','Раиса','Роза','Рита',
                        'Сабина','София','Стефания',
                        'Таисия','Татьяна',
                        'Эля','Эльга',
                        'Яна','Ярина',]
        
        self.surname_f = ['Алианна','Альяна','Атрасова','Апяткова','Авиолова','Анатошкина','Адианова','Асокина','Асотина','Алимарова',
                        'Бистибюлина','Бистинова','Бильбина','Балина','Базякина','Бурова','Батросова',
                        'Виталина','Верченко','Вистибюлина','Волчанова','Васюткина','Взирова','Ветрова','Вилина',
                        'Добровая','Дианнова','Деченко','Дякина','Дасимова','Добрич','Долинина',
                        'Етиспатова','Еровенич','Есушкина','Едурина',
                        'Жилинна','Жигулич','Житрипевич','Жигина','Жорина',
                        'Зимаидова','Зимина','Зосина','Зарецская','Замитрова','Зюсина',
                        'Ильнасова','Ирибинко','Истучева','Исшенко','Ипритова','Илизова','Иоритова',
                        'Кристальная','Кристинова','Космович',
                        'Ликрасова','Литрасова','Лобина','Логина','Лосинова',
                        'Миликанова','Мутулина','Марошина','Мертеич', 'Муратова', 'Матвеева','Мулина','Мастович',
                        'Никитова','Неримова','Настюшина','Николаева',
                        'Осенняя','Отмирова',
                        'Петрокамчатская','Полинина','Пирова','Пасутина',
                        'Роловинина','Ракусина','Рюрович','Руслаченко','Ралина','Родова',
                        'Сандалина','Семикрасова','Сачкова','Салтыкова','Спорина',
                        'Фёдорова','Филиморова','Филатова',
                        'Хирипова','Хиширина','Хочубина',
                        'Шевцова','Шитина','Шитрина',
                        'Эдолинова','Эльдарова','Эпченко','Эпистатова',
                        'Ютропова','Юлиева',
                        'Яркова','Яковлева','Ялубина','Явилина','Яшина',]
        
        self.num_part1 = ['805','810','820','850','870','880','890','895','899',]

        self.num_part2 = ['2415537','4636643','6438943','0077543','6536673','3564575','3513355','0006559',
                       '9997590','8654581','1010853','6695888','4256343','6476754','1215467','53674367',]
        
        self.email = ['rei793h','AlexHyIO','PORAMT1K','lsui1994','4345g2aw24y',
                      'georagl:wedmak','neomeo228','fifynya','930ip42','4444ererer4444',
                      'uow54io','xxxkeepmedownxxx','tytyr1n3','fil4rok','0101hh0101','QQooyyuurrnnIIwwqqxxzzQQ','popyt1k','tyrn1k','776',]
        
        self.email_index = ['@gmail.com','@outlook.com','@mcrs.com','@pytest.py',]

        self.faddres = ['Грибоедова','Ленина','Жаргонская','Сосоновая','Еловая',
                  'Пугачева','Комунистическая','Социалистическая','Дектярёва','Гагарина',
                  'Черная','Победителей','Мира','Малеева','Захарова', '20 октября']

    def fakename_male(self):
        fakenm = random.randint(0, len(self.name_m) -1)
        fakesm = random.randint(0, len(self.surname_m) -1)
        return(f'{self.name_m[fakenm]} {self.surname_m[fakesm]}')
    
    def fakename_female(self):
        fakenf = random.randint(0, len(self.name_f) -1)
        fakesf = random.randint(0, len(self.name_f) -1)
        return(f'{self.name_f[fakenf]} {self.surname_f[fakesf]}')

    def fake_number(self):
        fakenum1 = random.randint(0, len(self.num_part1) -1)
        fakenum2 = random.randint(0, len(self.num_part2) -1)
        return(f'+7{self.num_part1[fakenum1]}{self.num_part2[fakenum2]}')
    
    def fake_addres(self):
        fakeaddres = random.randint(0, len(self.faddres) -1)
        return(f'ул. {self.faddres[fakeaddres]} {random.randint(1, 120)}')
    
    def fake_email(self):
        fakeei = random.randint(0, len(self.email_index) -1)
        fakee = random.randint(0, len(self.email) -1)
        return(f'{self.email[fakee]}{self.email_index[fakeei]}')

if __name__ == '__main__':
    fu = Fu()
